MmapFlutter class

Flutter-specific initialization helper for Mmap

Constructors

MmapFlutter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isInitialized bool
Check if the library is initialized
no setter

Static Methods

initialize() → void
Initialize Mmap for Flutter applications
reset() → void
Reset initialization state (mainly for testing)